@@ -23,6 +23,7 @@ OC.L10N.register(
     "Week" : "هفته",
     "Month" : "ماه",
     "List" : "لیست",
+    "Delete" : "حذف",
     "Untitled calendar" : "تقویم بدون عنوان",
     "Edit name" : "ویرایش نام",
     "Saving name …" : "ذخیره نام",
@@ -31,7 +32,6 @@ OC.L10N.register(
     "Copy private link" : "کپی کردن پیوند خصوصی",
     "Download" : "دانلود",
     "Unshare from me" : "بی خبر از من",
-    "Delete" : "حذف",
     "An error occurred, unable to change visibility of the calendar." : "خطایی روی داد ، قادر به تغییر دیدگاه تقویم نیست.",
     "An error occurred, unable to delete the calendar." : "خطایی روی داد ، قادر به حذف تقویم نیست.",
     "Calendar link copied to clipboard." : "پیوند تقویم در کلیپ بورد کپی شد.",
@@ -40,7 +40,7 @@ OC.L10N.register(
     "An error occurred, unable to change the calendar's color." : "خطایی روی داد ، قادر به تغییر رنگ تقویم نیست.",
     "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["اشتراک‌گذاری تقویم در {شمارش معکوس}. ثانیه","اشتراک‌گذاری تقویم در {شمارش معکوس}. ثانیه ها"],
     "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["حذف تقویم در {شمارش معکوس} ثانیه ها","حذف تقویم در {شمارش معکوس} ثانیه ها"],
-    "Share link" : "Share link",
+    "Share link" : "لینک را به اشتراک بگذارید",
     "Publish calendar" : "تقویم را منتشر کنید",
     "Publishing calendar" : "در حال انتشار تقویم ",
     "Copy public link" : "پیوند عمومی را کپی کنید",
@@ -76,7 +76,6 @@ OC.L10N.register(
     "Creating subscription …" : "ایجاد اشتراک…",
     "An error occurred, unable to create the calendar." : "خطایی روی داد ، قادر به ایجاد تقویم نیست.",
     "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "لطفاً یک پیوند معتبر وارد کنید (با شروع http: // ، https: // ، webcal: // ، یا صفحات وب: //)",
-    "Untitled event" : "رویداد بدون عنوان",
     "Import calendars" : "وارد کردن تقویم ها",
     "Please select a calendar to import into …" : "لطفاً یک تقویم را برای وارد کردن به… انتخاب کنید",
     "Filename" : "نام فایل",
@@ -98,6 +97,11 @@ OC.L10N.register(
     "Settings & import" : "تنظیمات و وارد کردن",
     "CalDAV link copied to clipboard." : "پیوند CalDAV در کلیپ بورد کپی شد.",
     "CalDAV link could not be copied to clipboard." : "پیوند CalDAV در کلیپ بورد قابل کپی نیست.",
+    "Location" : "محل",
+    "Description" : "توضیحات",
+    "Monday" : "دوشنبه",
+    "Save" : "ذخیره",
+    "Update" : "به روز رسانی",
     "before at" : "قبل از در",
     "Notification" : "اطلاع",
     "Email" : "ایمیل",
@@ -116,7 +120,6 @@ OC.L10N.register(
     "_hour_::_hours_" : ["ساعت","ساعت ها"],
     "_day_::_days_" : ["روز","روز ها"],
     "_week_::_weeks_" : ["هفته","هفته ها"],
-    "No reminders yet" : "هنوز هیچ یادآوری نیست",
     "Availability of attendees, resources and rooms" : "در دسترس بودن شرکت کنندگان ، منابع و اتاق ها",
     "Free" : "رایگان",
     "Busy (tentative)" : "مشغول (آزمایشی)",
@@ -125,6 +128,7 @@ OC.L10N.register(
     "Unknown" : "نامشخص",
     "Create Talk room for this event" : "اتاق گفتگو را برای این رویداد ایجاد کنید",
     "Show busy times" : " نمایش  زمان‌های  شلوغ",
+    "No attendees yet" : "هنوز هیچ حضوری وجود ندارد",
     "Successfully appended link to talk room to description." : "پیوند موفقیت آمیز پیوند به اتاق گفتگو به توضیحات.",
     "Error creating Talk room" : "خطا در ایجاد اتاق گفتگو",
     "Chairperson" : "رئیس",
@@ -133,7 +137,6 @@ OC.L10N.register(
     "Non-participant" : "غیر شرکت کننده",
     "Remove attendee" : "شرکت کننده را حذف کنید",
     "No match found" : "هیچ تطبیقی یافت نشد",
-    "No attendees yet" : "هنوز هیچ حضوری وجود ندارد",
     "(organizer)" : "(تنظیم کننده)",
     "Event title" : "عنوان رویداد",
     "All day" : "تمام روز",
@@ -141,6 +144,7 @@ OC.L10N.register(
     "from {startDate} at {startTime}" : "از {startDate} در {startTime}",
     "to {endDate}" : "به {endDate}",
     "to {endDate} at {endTime}" : "به {endDate} در {endTime}",
+    "Repeat" : "تکرار",
     "End repeat" : "پایان تکرار ",
     "Select to end repeat" : "برای پایان دادن به تکرار انتخاب کنید",
     "never" : "هرگز",
@@ -154,25 +158,19 @@ OC.L10N.register(
     "second to last" : "دوم تا آخرین",
     "last" : "آخر",
     "Changes to the recurrence-rule will only apply to this and all future occurrences." : "تغییر در قانون بازگشتی فقط در مورد این و همه وقایع آینده اعمال خواهد شد.",
-    "Repeat" : "تکرار",
     "Repeat every" : "همه را تکرار کنید",
     "By day of the month" : "تا روز ماه",
     "On the" : "در",
     "_month_::_months_" : ["ماه","ماه ها"],
     "_year_::_years_" : ["سال","سال ها"],
-    "Monday" : "دوشنبه",
     "weekday" : "روز هفته",
     "weekend day" : " آخر  هفته",
-    "Summary" : "خلاصه",
     "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "تعریف بازگشتی از این رویداد توسط نکست کلود کاملاً پشتیبانی نمی شود. اگر گزینه های بازگشتی را ویرایش کنید ، ممکن است بازگشتی های خاصی از بین بروند.",
     "More" : "بیش‌تر",
-    "Save" : "ذخیره",
-    "Update" : "به روز رسانی",
     "Update this occurrence" : "این رویداد را به روز کنید",
     "Update this and all future" : "این و همه آینده را به روز کنید",
     "Public calendar does not exist" : "تقویم عمومی وجود ندارد",
     "Maybe the share was deleted or has expired?" : "شاید اشتراک حذف شده باشد یا منقضی شده باشد؟",
-    "Please select a timezone:" : "لطفا منطقه زمانی را انتخاب کنید:",
     "from {formattedDate}" : "از {formattedDate}",
     "to {formattedDate}" : "به {formattedDate}",
     "on {formattedDate}" : "در {formattedDate}",
@@ -182,15 +180,12 @@ OC.L10N.register(
     "{formattedDate} at {formattedTime}" : "{formattedDate} در {formattedTime}",
     "Please enter a valid date" : "لطفا یک تاریخ معتبر وارد کنید",
     "Please enter a valid date and time" : "لطفاً یک تاریخ و زمان معتبر وارد کنید",
-    "Type to search timezone" : "برای جستجو در منطقه زمانی تایپ کنید",
+    "Global" : "عمومی",
     "Personal" : "شخصی",
-    "The automatic timezone detection determined your timezone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your timezone manually in the calendar settings." : "تشخیص منطقه زمانی خودکار ، منطقه زمانی شما را UTC تعیین می کند. این احتمالاً نتیجه اقدامات امنیتی مرورگر وب شماست. لطفاً منطقه زمانی خود را به صورت دستی در تنظیمات تقویم تنظیم کنید.",
-    "Your configured timezone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your timezone in the settings and report this issue." : "منطقه زمانی پیکربندی شده شما ({timezoneId}) یافت نشد. در حال بازگشت به UTC. لطفاً منطقه زمانی خود را در تنظیمات تغییر داده و این مسئله را گزارش کنید.",
     "Delete this occurrence" : "این رخداد را حذف کنید",
     "Delete this and all future" : "این و همه آینده را حذف کنید",
     "Details" : "جزئیات",
     "Attendees" : "شرکت کنندگان",
-    "Reminders" : "یادآوری ها",
     "Close" : "بستن",
     "Show more details" : "جزئیات بیشتر را نشان دهید",
     "Subscribe to {name}" : "اشتراک در {name}",
@@ -238,15 +233,14 @@ OC.L10N.register(
     "in {monthNames} on the {ordinalNumber} {byDaySet}" : "در {monthNames} در {ordinalNumber} {byDaySet}",
     "until {untilDate}" : "تا زمان {untilDate}",
     "_%n time_::_%n times_" : ["%n بار","%n بارها"],
+    "Untitled event" : "رویداد بدون عنوان",
     "_+%n more_::_+%n more_" : ["+%n بیشتر","+%n بیشتر"],
     "When shared show" : "هنگام نمایش مشترک",
     "When shared show full event" : "هنگام اشتراک گذاری ، رویداد کامل را نشان می دهد",
     "When shared show only busy" : "وقتی نمایش اشتراکی فقط مشغول است",
     "When shared hide this event" : "هنگام اشتراک گذاری این رویداد را پنهان کنید",
     "The visibility of this event in shared calendars." : "قابلیت مشاهده این رویداد در تقویمهای مشترک.",
-    "Location" : "محل",
     "Add a location" : "اضافه کردن یک محل",
-    "Description" : "توضیحات",
     "Add a description" : "توضیحات اضافه کنید",
     "Status" : "وضعیت",
     "Confirmed" : "تایید شده",
@@ -342,7 +336,6 @@ OC.L10N.register(
     "Wine tasting" : "مزه کردن شراب",
     "Golf" : "گلف",
     "Dinner" : "شام",
-    "Lunch" : "ناهار",
-    "Global" : "عمومی"
+    "Lunch" : "ناهار"
 },
 "nplurals=2; plural=(n > 1);");
