@@ -8,8 +8,8 @@ OC.L10N.register(
     "Day" : "Die",
     "Week" : "Septimana",
     "Month" : "Mense",
-    "Download" : "Discargar",
     "Delete" : "Deler",
+    "Download" : "Discargar",
     "Share link" : "Compartir ligamine",
     "Share with users or groups" : "Compartir con usatores o gruppos",
     "can edit" : "pote modificar",
@@ -19,20 +19,21 @@ OC.L10N.register(
     "Actions" : "Actiones",
     "Show week numbers" : "Monstrar le numero del septimanas",
     "Settings & import" : "Configurationes e importation",
-    "Email" : "E-posta",
-    "Unknown" : "Incognite",
-    "never" : "nunquam",
-    "after" : "post",
-    "Repeat" : "Repeter",
+    "Location" : "Loco",
+    "Description" : "Description",
     "Monday" : "Lunedi",
-    "Summary" : "Summario",
-    "More" : "Plus",
     "Save" : "Salveguardar",
     "Update" : "Actualisar",
+    "Email" : "E-posta",
+    "Unknown" : "Incognite",
+    "Repeat" : "Repeter",
+    "never" : "nunquam",
+    "after" : "post",
+    "More" : "Plus",
+    "Global" : "Global",
     "Personal" : "Personal",
     "Details" : "Detalios",
     "Attendees" : "Participantes",
-    "Reminders" : "Memento",
     "Close" : "Clauder",
     "Anniversary" : "Anniversario de evento",
     "Week {number} of {year}" : "Septimana {number} de {year}",
@@ -41,12 +42,9 @@ OC.L10N.register(
     "When shared show full event" : "Quando compartite, monstrar evento integremente",
     "When shared show only busy" : "Quando compartite, monstrar solo si illo es occupate",
     "When shared hide this event" : "Quando compartite, celar iste evento",
-    "Location" : "Loco",
-    "Description" : "Description",
     "Confirmed" : "Confirmate",
     "Tentative" : "Tentative",
     "Presentation" : "Presentation",
-    "Mail" : "Posta",
-    "Global" : "Global"
+    "Mail" : "Posta"
 },
 "nplurals=2; plural=(n != 1);");
