@@ -23,59 +23,44 @@ declare(strict_types=1);
  */
 namespace OCA\Calendar\Controller;
 
+use OCA\Calendar\Service\Appointments\AppointmentConfigService;
 use OCP\App\IAppManager;
 use OCP\AppFramework\Controller;
 use OCP\AppFramework\Http\TemplateResponse;
+use OCP\AppFramework\Services\IInitialState;
 use OCP\IConfig;
-use OCP\IInitialStateService;
 use OCP\IRequest;
 
-/**
- * Class ViewController
- *
- * @package OCA\Calendar\Controller
- */
 class ViewController extends Controller {
 
-	/**
-	 * @var IConfig
-	 */
+	/** @var IConfig */
 	private $config;
 
-	/**
-	 * @var string
-	 */
-	private $userId;
+	/** @var AppointmentConfigService */
+	private $appointmentConfigService;
 
-	/**
-	 * @var IInitialStateService
-	 */
+	/** @var IInitialState */
 	private $initialStateService;
 
-	/**
-	 * @var IAppManager
-	 */
+	/** @var IAppManager */
 	private $appManager;
 
-	/**
-	 * @param string $appName
-	 * @param IRequest $request an instance of the request
-	 * @param IConfig $config
-	 * @param IInitialStateService $initialStateService
-	 * @param IAppManager $appManager
-	 * @param string $userId
-	 */
+	/** @var string */
+	private $userId;
+
 	public function __construct(string $appName,
 								IRequest $request,
 								IConfig $config,
-								IInitialStateService $initialStateService,
+								AppointmentConfigService $appointmentConfigService,
+								IInitialState $initialStateService,
 								IAppManager $appManager,
 								?string $userId) {
 		parent::__construct($appName, $request);
 		$this->config = $config;
-		$this->userId = $userId;
+		$this->appointmentConfigService = $appointmentConfigService;
 		$this->initialStateService = $initialStateService;
 		$this->appManager = $appManager;
+		$this->userId = $userId;
 	}
 
 	/**
@@ -113,20 +98,24 @@ class ViewController extends Controller {
 		$talkApiVersion = version_compare($this->appManager->getAppVersion('spreed'), '12.0.0', '>=') ? 'v4' : 'v1';
 		$tasksEnabled = $this->appManager->isEnabledForUser('tasks');
 
-		$this->initialStateService->provideInitialState($this->appName, 'app_version', $appVersion);
-		$this->initialStateService->provideInitialState($this->appName, 'event_limit', $eventLimit);
-		$this->initialStateService->provideInitialState($this->appName, 'first_run', $firstRun);
-		$this->initialStateService->provideInitialState($this->appName, 'initial_view', $initialView);
-		$this->initialStateService->provideInitialState($this->appName, 'show_weekends', $showWeekends);
-		$this->initialStateService->provideInitialState($this->appName, 'show_week_numbers', $showWeekNumbers);
-		$this->initialStateService->provideInitialState($this->appName, 'skip_popover', $skipPopover);
-		$this->initialStateService->provideInitialState($this->appName, 'talk_enabled', $talkEnabled);
-		$this->initialStateService->provideInitialState($this->appName, 'talk_api_version', $talkApiVersion);
-		$this->initialStateService->provideInitialState($this->appName, 'timezone', $timezone);
-		$this->initialStateService->provideInitialState($this->appName, 'slot_duration', $slotDuration);
-		$this->initialStateService->provideInitialState($this->appName, 'default_reminder', $defaultReminder);
-		$this->initialStateService->provideInitialState($this->appName, 'show_tasks', $showTasks);
-		$this->initialStateService->provideInitialState($this->appName, 'tasks_enabled', $tasksEnabled);
+		$this->initialStateService->provideInitialState('app_version', $appVersion);
+		$this->initialStateService->provideInitialState('event_limit', $eventLimit);
+		$this->initialStateService->provideInitialState('first_run', $firstRun);
+		$this->initialStateService->provideInitialState('initial_view', $initialView);
+		$this->initialStateService->provideInitialState('show_weekends', $showWeekends);
+		$this->initialStateService->provideInitialState('show_week_numbers', $showWeekNumbers);
+		$this->initialStateService->provideInitialState('skip_popover', $skipPopover);
+		$this->initialStateService->provideInitialState('talk_enabled', $talkEnabled);
+		$this->initialStateService->provideInitialState('talk_api_version', $talkApiVersion);
+		$this->initialStateService->provideInitialState('timezone', $timezone);
+		$this->initialStateService->provideInitialState('slot_duration', $slotDuration);
+		$this->initialStateService->provideInitialState('default_reminder', $defaultReminder);
+		$this->initialStateService->provideInitialState('show_tasks', $showTasks);
+		$this->initialStateService->provideInitialState('tasks_enabled', $tasksEnabled);
+		$this->initialStateService->provideInitialState(
+			'appointmentConfigs',
+			$this->appointmentConfigService->getAllAppointmentConfigurations($this->userId),
+		);
 
 		return new TemplateResponse($this->appName, 'main');
 	}
